@@ -7,6 +7,9 @@
 glmReserve <- function(triangle, var.power = 1, link.power = 0,
                        cum = TRUE, mse.method = c("formula", "bootstrap"), 
                        nsim = 1000, ...){
+  if (is.null(var.power))
+    stop("var.power must be provided for this version")
+  
   call <- match.call()
   mse.method <- match.arg(mse.method)
   
@@ -25,7 +28,9 @@ glmReserve <- function(triangle, var.power = 1, link.power = 0,
   fam <- tweedie(ifelse(!is.null(var.power), var.power, 1.5), link.power)
   
   # convert to long format
-  lda <-  as.data.frame(tr.incr)
+  lda <-  as.data.frame(tr.incr, origin=names(dimnames(tr.incr))[1], 
+                        dev=names(dimnames(tr.incr))[2])
+  names(lda)[1:3] <- c("origin", "dev", "value")
   
   # create offset
   if (is.null(attr(tr.incr, "exposure"))) {
@@ -44,11 +49,11 @@ glmReserve <- function(triangle, var.power = 1, link.power = 0,
               data = ldaFit, offset = offset, ...)
     phi <- with(glmFit, sum(weights * residuals^2) / df.residual)
   } else{ 
-    glmFit <- cpglm(value ~ factor(origin) + factor(dev),
-                  link = link.power, data = ldaFit, offset = offset, ...)
-    phi <- glmFit$phi
+    #glmFit <- cpglm(value ~ factor(origin) + factor(dev),
+    #              link = link.power, data = ldaFit, offset = offset, ...)
+    #phi <- glmFit$phi
     # update fam
-    fam <- tweedie(glmFit$p, link.power)
+    #fam <- tweedie(glmFit$p, link.power)
   }
 
   ################################
@@ -129,9 +134,9 @@ glmReserve <- function(triangle, var.power = 1, link.power = 0,
         phi <- with(glmFitB, sum(weights * residuals^2) / df.residual)
         cf <- c(coef(glmFitB), phi, var.power)
       } else{ 
-        glmFitB <- cpglm(yB ~ factor(origin) + factor(dev),
-                        link = link.power, data = ldaFit, offset = offset, ...)
-        cf <- c(coef(glmFitB), glmFitB$phi, glmFitB$p)
+        #glmFitB <- cpglm(yB ~ factor(origin) + factor(dev),
+        #                link = link.power, data = ldaFit, offset = offset, ...)
+        #cf <- c(coef(glmFitB), glmFitB$phi, glmFitB$p)
       }      
       # mean and prediction
       ymB <- predict(glmFitB, newdata = ldaOut, type = "response")
