@@ -1,64 +1,68 @@
 ### R code from vignette source 'ChainLadder.Rnw'
+### Encoding: UTF-8
 
 ###################################################
 ### code chunk number 1: options
 ###################################################
-options(prompt = "R> ", digits = 4, show.signif.stars = FALSE)
+library(lattice)
+options(prompt = "R> ", digits = 4, show.signif.stars = TRUE)
+options(continue="   ")
+lattice.options(default.theme = standard.theme(color = FALSE))
 
 
 ###################################################
-### code chunk number 2: ChainLadder.Rnw:192-193 (eval = FALSE)
+### code chunk number 2: ChainLadder.Rnw:219-220 (eval = FALSE)
 ###################################################
 ## demo(package="ChainLadder")
 
 
 ###################################################
-### code chunk number 3: ChainLadder.Rnw:196-198 (eval = FALSE)
+### code chunk number 3: ChainLadder.Rnw:223-225 (eval = FALSE)
 ###################################################
 ## library(ChainLadder)
 ## demo("demo name")
 
 
 ###################################################
-### code chunk number 4: ChainLadder.Rnw:207-208 (eval = FALSE)
+### code chunk number 4: ChainLadder.Rnw:234-235 (eval = FALSE)
 ###################################################
 ## install.packages('ChainLadder') 
 
 
 ###################################################
-### code chunk number 5: ChainLadder.Rnw:213-214
+### code chunk number 5: ChainLadder.Rnw:240-241
 ###################################################
 library(ChainLadder)
 
 
 ###################################################
-### code chunk number 6: ChainLadder.Rnw:216-217 (eval = FALSE)
+### code chunk number 6: ChainLadder.Rnw:243-244 (eval = FALSE)
 ###################################################
 ## library(ChainLadder)
 
 
 ###################################################
-### code chunk number 7: ChainLadder.Rnw:219-220
+### code chunk number 7: ChainLadder.Rnw:246-247
 ###################################################
 cat(ChainLadder:::chainladderWelcomeMessage())
 
 
 ###################################################
-### code chunk number 8: ChainLadder.Rnw:236-238 (eval = FALSE)
+### code chunk number 8: ChainLadder.Rnw:271-273 (eval = FALSE)
 ###################################################
 ## require(ChainLadder)
 ## data(package="ChainLadder")
 
 
 ###################################################
-### code chunk number 9: ChainLadder.Rnw:243-245
+### code chunk number 9: ChainLadder.Rnw:278-280
 ###################################################
 ## Sample triangle
 RAA
 
 
 ###################################################
-### code chunk number 10: ChainLadder.Rnw:272-273 (eval = FALSE)
+### code chunk number 10: ChainLadder.Rnw:307-308 (eval = FALSE)
 ###################################################
 ## plot(RAA)
 
@@ -70,7 +74,7 @@ plot(RAA)
 
 
 ###################################################
-### code chunk number 12: ChainLadder.Rnw:292-293 (eval = FALSE)
+### code chunk number 12: ChainLadder.Rnw:327-328 (eval = FALSE)
 ###################################################
 ## plot(RAA, lattice=TRUE)
 
@@ -82,13 +86,13 @@ plot(RAA, lattice=TRUE)
 
 
 ###################################################
-### code chunk number 14: ChainLadder.Rnw:313-314 (eval = FALSE)
+### code chunk number 14: ChainLadder.Rnw:348-349 (eval = FALSE)
 ###################################################
 ## ?plot.triangle
 
 
 ###################################################
-### code chunk number 15: ChainLadder.Rnw:322-328
+### code chunk number 15: ChainLadder.Rnw:357-363
 ###################################################
 raa.inc <- cum2incr(RAA)
 ## Show first origin period and its incremental development
@@ -99,13 +103,13 @@ raa.cum[1,]
 
 
 ###################################################
-### code chunk number 16: ChainLadder.Rnw:338-339 (eval = FALSE)
+### code chunk number 16: ChainLadder.Rnw:375-376 (eval = FALSE)
 ###################################################
 ## demo(DatabaseExamples)
 
 
 ###################################################
-### code chunk number 17: ChainLadder.Rnw:354-360
+### code chunk number 17: ChainLadder.Rnw:393-399
 ###################################################
 filename <-  file.path(system.file("Database", 
                                    package="ChainLadder"), 
@@ -116,14 +120,14 @@ summary(myData)
 
 
 ###################################################
-### code chunk number 18: ChainLadder.Rnw:363-365
+### code chunk number 18: ChainLadder.Rnw:402-404
 ###################################################
 raa <- subset(myData, lob %in% "RAA")
 head(raa)
 
 
 ###################################################
-### code chunk number 19: ChainLadder.Rnw:371-376
+### code chunk number 19: ChainLadder.Rnw:410-415
 ###################################################
 raa.tri <- as.triangle(raa, 
                        origin="origin", 
@@ -133,26 +137,26 @@ raa.tri
 
 
 ###################################################
-### code chunk number 20: ChainLadder.Rnw:383-385
+### code chunk number 20: ChainLadder.Rnw:422-424
 ###################################################
 raa.df <- as.data.frame(raa.tri, na.rm=TRUE)
 head(raa.df)
 
 
 ###################################################
-### code chunk number 21: ChainLadder.Rnw:404-405 (eval = FALSE)
+### code chunk number 21: ChainLadder.Rnw:443-444 (eval = FALSE)
 ###################################################
 ## x <- read.table(file="clipboard", sep="\t", na.strings="")
 
 
 ###################################################
-### code chunk number 22: ChainLadder.Rnw:410-411 (eval = FALSE)
+### code chunk number 22: ChainLadder.Rnw:449-450 (eval = FALSE)
 ###################################################
 ## write.table(RAA, file="clipboard", sep="\t", na="")
 
 
 ###################################################
-### code chunk number 23: ChainLadder.Rnw:431-438
+### code chunk number 23: ChainLadder.Rnw:470-477
 ###################################################
 n <- 10
 f <- sapply(1:(n-1), 
@@ -164,7 +168,7 @@ f
 
 
 ###################################################
-### code chunk number 24: ChainLadder.Rnw:444-453
+### code chunk number 24: ChainLadder.Rnw:483-492
 ###################################################
 dev.period <- 1:(n-1)
 plot(log(f-1) ~ dev.period, main="Log-linear extrapolation of age-to-age factors")
@@ -178,7 +182,7 @@ f.tail
 
 
 ###################################################
-### code chunk number 25: ChainLadder.Rnw:458-461
+### code chunk number 25: ChainLadder.Rnw:497-500
 ###################################################
 plot(100*(rev(1/cumprod(rev(c(f, tail[tail>1.0001]))))), t="b",
      main="Expected claims development pattern",
@@ -186,7 +190,7 @@ plot(100*(rev(1/cumprod(rev(c(f, tail[tail>1.0001]))))), t="b",
 
 
 ###################################################
-### code chunk number 26: ChainLadder.Rnw:470-476
+### code chunk number 26: ChainLadder.Rnw:509-515
 ###################################################
 f <- c(f, f.tail)
 fullRAA <- cbind(RAA, Ult = rep(0, 10))
@@ -197,13 +201,13 @@ round(fullRAA)
 
 
 ###################################################
-### code chunk number 27: ChainLadder.Rnw:480-481
+### code chunk number 27: ChainLadder.Rnw:519-520
 ###################################################
 sum(fullRAA[ ,11] - getLatestCumulative(RAA))
 
 
 ###################################################
-### code chunk number 28: ChainLadder.Rnw:504-520
+### code chunk number 28: ChainLadder.Rnw:543-559
 ###################################################
 linkratios <- c(attr(ata(RAA), "vwtd"), tail = 1.05)
 round(linkratios, 3) # display to only three decimal places
@@ -224,7 +228,7 @@ Exhibit
 
 
 ###################################################
-### code chunk number 29: ChainLadder.Rnw:529-534
+### code chunk number 29: ChainLadder.Rnw:568-573
 ###################################################
 lmCL <- function(i, Triangle){
   lm(y~x+0, weights=1/Triangle[,i],
@@ -234,14 +238,14 @@ sapply(lapply(c(1:(n-1)), lmCL, RAA), coef)
 
 
 ###################################################
-### code chunk number 30: ChainLadder.Rnw:574-576
+### code chunk number 30: ChainLadder.Rnw:613-615
 ###################################################
 mack <- MackChainLadder(RAA, est.sigma="Mack")
 mack
 
 
 ###################################################
-### code chunk number 31: ChainLadder.Rnw:579-581
+### code chunk number 31: ChainLadder.Rnw:618-620
 ###################################################
 mack$f
 mack$FullTriangle
@@ -260,41 +264,7 @@ plot(mack, lattice=TRUE)
 
 
 ###################################################
-### code chunk number 34: ChainLadder.Rnw:616-620
-###################################################
-## See also the example in section 8 of England & Verrall (2002) 
-## on page 55.
-B <- BootChainLadder(RAA, R=999, process.distr="gamma")
-B
-
-
-###################################################
-### code chunk number 35: ChainLadder.Rnw:624-625
-###################################################
-plot(B)
-
-
-###################################################
-### code chunk number 36: ChainLadder.Rnw:631-632
-###################################################
-quantile(B, c(0.75,0.95,0.99, 0.995))
-
-
-###################################################
-### code chunk number 37: ChainLadder.Rnw:636-644
-###################################################
-## fit a distribution to the IBNR
-library(MASS)
-plot(ecdf(B$IBNR.Totals))
-## fit a log-normal distribution 
-fit <- fitdistr(B$IBNR.Totals[B$IBNR.Totals>0], "lognormal")
-fit
-curve(plnorm(x,fit$estimate["meanlog"], fit$estimate["sdlog"]),
-      col="red", add=TRUE)  
-
-
-###################################################
-### code chunk number 38: ChainLadder.Rnw:651-662
+### code chunk number 34: ChainLadder.Rnw:649-660
 ###################################################
 MCLpaid
 MCLincurred
@@ -310,46 +280,80 @@ plot(MCL)
 
 
 ###################################################
-### code chunk number 39: ChainLadder.Rnw:720-721
+### code chunk number 35: ChainLadder.Rnw:677-681
+###################################################
+## See also the example in section 8 of England & Verrall (2002) 
+## on page 55.
+B <- BootChainLadder(RAA, R=999, process.distr="gamma")
+B
+
+
+###################################################
+### code chunk number 36: ChainLadder.Rnw:685-686
+###################################################
+plot(B)
+
+
+###################################################
+### code chunk number 37: ChainLadder.Rnw:692-693
+###################################################
+quantile(B, c(0.75,0.95,0.99, 0.995))
+
+
+###################################################
+### code chunk number 38: ChainLadder.Rnw:697-705
+###################################################
+## fit a distribution to the IBNR
+library(MASS)
+plot(ecdf(B$IBNR.Totals))
+## fit a log-normal distribution 
+fit <- fitdistr(B$IBNR.Totals[B$IBNR.Totals>0], "lognormal")
+fit
+curve(plnorm(x,fit$estimate["meanlog"], fit$estimate["sdlog"]),
+      col="red", add=TRUE)  
+
+
+###################################################
+### code chunk number 39: ChainLadder.Rnw:763-764
 ###################################################
 str(liab)
 
 
 ###################################################
-### code chunk number 40: ChainLadder.Rnw:724-726
+### code chunk number 40: ChainLadder.Rnw:767-769
 ###################################################
 liab2 <- as(liab, "triangles")
 class(liab2)
 
 
 ###################################################
-### code chunk number 41: ChainLadder.Rnw:729-730 (eval = FALSE)
+### code chunk number 41: ChainLadder.Rnw:772-773 (eval = FALSE)
 ###################################################
 ## showMethods(classes = "triangles")
 
 
 ###################################################
-### code chunk number 42: ChainLadder.Rnw:734-736
+### code chunk number 42: ChainLadder.Rnw:777-779
 ###################################################
 # use drop = TRUE to remove rows that are all NA's
 liab2[, 12:14, drop = TRUE]
 
 
 ###################################################
-### code chunk number 43: ChainLadder.Rnw:739-740
+### code chunk number 43: ChainLadder.Rnw:782-783
 ###################################################
 cbind2(liab2[1:3, 12])
 
 
 ###################################################
-### code chunk number 44: ChainLadder.Rnw:753-755
+### code chunk number 44: ChainLadder.Rnw:796-798
 ###################################################
 fit1 <- MultiChainLadder(liab, fit.method = "OLS")
 lapply(summary(fit1)$report.summary, "[", 15, )
 
 
 ###################################################
-### code chunk number 45: ChainLadder.Rnw:769-772
+### code chunk number 45: ChainLadder.Rnw:812-815
 ###################################################
 fit <- lapply(liab, MackChainLadder, est.sigma = "Mack")
 # the same as the first triangle above
@@ -357,33 +361,33 @@ lapply(fit, function(x) t(summary(x)$Totals))
 
 
 ###################################################
-### code chunk number 46: ChainLadder.Rnw:784-786
+### code chunk number 46: ChainLadder.Rnw:827-829
 ###################################################
 (B1 <- MultiChainLadder(list(GenIns), fit.method = "OLS", 
     mse.method = "Independence"))
 
 
 ###################################################
-### code chunk number 47: ChainLadder.Rnw:795-797
+### code chunk number 47: ChainLadder.Rnw:838-840
 ###################################################
 fit2 <- MultiChainLadder(liab, fit.method = "SUR")
 lapply(summary(fit2)$report.summary, "[", 15, )
 
 
 ###################################################
-### code chunk number 48: ChainLadder.Rnw:804-805
+### code chunk number 48: ChainLadder.Rnw:847-848
 ###################################################
 round(unlist(residCor(fit2)), 3)
 
 
 ###################################################
-### code chunk number 49: ChainLadder.Rnw:812-813
+### code chunk number 49: ChainLadder.Rnw:855-856
 ###################################################
 do.call("rbind", coef(fit2))
 
 
 ###################################################
-### code chunk number 50: ChainLadder.Rnw:821-825 (eval = FALSE)
+### code chunk number 50: ChainLadder.Rnw:864-868 (eval = FALSE)
 ###################################################
 ## parold <- par(mfrow = c(4, 2), mar = c(4, 4, 2, 1), 
 ##     mgp = c(1.3, 0.3, 0), tck = -0.02)
@@ -401,7 +405,7 @@ par(parold)
 
 
 ###################################################
-### code chunk number 52: ChainLadder.Rnw:887-890
+### code chunk number 52: ChainLadder.Rnw:930-933
 ###################################################
 W1 <- MultiChainLadder2(liab, mse.method = "Independence", 
       	control = systemfit.control(methodResidCov = "Theil"))
@@ -409,7 +413,7 @@ lapply(summary(W1)$report.summary, "[", 15, )
 
 
 ###################################################
-### code chunk number 53: ChainLadder.Rnw:896-903
+### code chunk number 53: ChainLadder.Rnw:939-946
 ###################################################
 for (i in 1:5){
   W2 <- MultiChainLadder2(liab, mse.method = "Independence", 
@@ -421,13 +425,13 @@ lapply(summary(W2)$report.summary, "[", 15, )
 
 
 ###################################################
-### code chunk number 54: ChainLadder.Rnw:922-923
+### code chunk number 54: ChainLadder.Rnw:965-966
 ###################################################
 str(auto)
 
 
 ###################################################
-### code chunk number 55: ChainLadder.Rnw:927-931
+### code chunk number 55: ChainLadder.Rnw:970-974
 ###################################################
 f0 <- MultiChainLadder2(auto, type = "MCL")
 # show correlation- the last three columns have zero correlation
@@ -436,7 +440,7 @@ print(do.call(cbind, residCor(f0)), digits = 3)
 
 
 ###################################################
-### code chunk number 56: ChainLadder.Rnw:940-941
+### code chunk number 56: ChainLadder.Rnw:983-984
 ###################################################
 f1 <- MultiChainLadder2(auto, type = "MCL+int")
 
@@ -452,20 +456,20 @@ par(parold)
 
 
 ###################################################
-### code chunk number 58: ChainLadder.Rnw:967-968
+### code chunk number 58: ChainLadder.Rnw:1010-1011
 ###################################################
 lapply(summary(f1, portfolio = "1+3")@report.summary, "[", 11, )
 
 
 ###################################################
-### code chunk number 59: ChainLadder.Rnw:977-979
+### code chunk number 59: ChainLadder.Rnw:1020-1022
 ###################################################
 ult <- summary(f1)$Ultimate
 print(ult[, 1] /ult[, 2], 3)
 
 
 ###################################################
-### code chunk number 60: ChainLadder.Rnw:990-1006
+### code chunk number 60: ChainLadder.Rnw:1033-1049
 ###################################################
 da <- auto[1:2]
 # MCL with diagonal development
@@ -486,19 +490,19 @@ print(do.call(cbind, c(r1, list(MuCl = r2))) * 100, digits = 4)
 
 
 ###################################################
-### code chunk number 61: ChainLadder.Rnw:1058-1059
+### code chunk number 61: ChainLadder.Rnw:1101-1102
 ###################################################
 ClarkLDF(RAA)
 
 
 ###################################################
-### code chunk number 62: ChainLadder.Rnw:1069-1070
+### code chunk number 62: ChainLadder.Rnw:1112-1113
 ###################################################
 ClarkLDF(RAA, maxage = 20)
 
 
 ###################################################
-### code chunk number 63: ChainLadder.Rnw:1074-1075
+### code chunk number 63: ChainLadder.Rnw:1117-1118
 ###################################################
 ClarkLDF(RAA, G="weibull")
 
@@ -510,7 +514,7 @@ plot(ClarkLDF(RAA, G="weibull"))
 
 
 ###################################################
-### code chunk number 65: ChainLadder.Rnw:1103-1104
+### code chunk number 65: ChainLadder.Rnw:1146-1147
 ###################################################
 ClarkCapeCod(RAA, Premium = 40000, G = "weibull")
 
@@ -522,7 +526,7 @@ plot(ClarkCapeCod(RAA, Premium = 40000, G = "weibull"))
 
 
 ###################################################
-### code chunk number 67: ChainLadder.Rnw:1161-1166
+### code chunk number 67: ChainLadder.Rnw:1204-1209
 ###################################################
 # load data 
 data(GenIns)
@@ -532,13 +536,13 @@ GenIns <- GenIns / 1000
 
 
 ###################################################
-### code chunk number 68: ChainLadder.Rnw:1170-1171
+### code chunk number 68: ChainLadder.Rnw:1213-1214
 ###################################################
 summary(fit1, type = "model")
 
 
 ###################################################
-### code chunk number 69: ChainLadder.Rnw:1176-1180
+### code chunk number 69: ChainLadder.Rnw:1219-1223
 ###################################################
 # Gamma GLM
 (fit2 <- glmReserve(GenIns, var.power = 2))
@@ -547,20 +551,20 @@ summary(fit1, type = "model")
 
 
 ###################################################
-### code chunk number 70: ChainLadder.Rnw:1188-1190
+### code chunk number 70: ChainLadder.Rnw:1231-1233
 ###################################################
 set.seed(11)
 (fit5 <- glmReserve(GenIns, mse.method = "boot"))
 
 
 ###################################################
-### code chunk number 71: ChainLadder.Rnw:1197-1198
+### code chunk number 71: ChainLadder.Rnw:1240-1241
 ###################################################
 names(fit5)
 
 
 ###################################################
-### code chunk number 72: ChainLadder.Rnw:1203-1207
+### code chunk number 72: ChainLadder.Rnw:1246-1250
 ###################################################
 pr <- as.data.frame(fit5$sims.reserve.pred)
 qv <- c(0.025, 0.25, 0.5, 0.75, 0.975)
@@ -569,7 +573,7 @@ print(format(round(res.q), big.mark = ","), quote = FALSE)
 
 
 ###################################################
-### code chunk number 73: ChainLadder.Rnw:1213-1222 (eval = FALSE)
+### code chunk number 73: ChainLadder.Rnw:1256-1265 (eval = FALSE)
 ###################################################
 ## library(ggplot2)
 ## library(reshape2)
@@ -583,19 +587,45 @@ print(format(round(res.q), big.mark = ","), quote = FALSE)
 
 
 ###################################################
-### code chunk number 74: ChainLadder.Rnw:1239-1240 (eval = FALSE)
+### code chunk number 74: ChainLadder.Rnw:1322-1325
+###################################################
+M <- MackChainLadder(MW2014, est.sigma="Mack")
+cdrM <- CDR(M)
+round(cdrM, 1)
+
+
+###################################################
+### code chunk number 75: tweedieReserve (eval = FALSE)
+###################################################
+##  p_profile <- tweedieReserve(MW2008, p.optim=TRUE, 
+##    p.check=c(0,1.1,1.2,1.3,1.4,1.5,2,3),
+##    design.type=c(0,1,1), 
+##    rereserving=FALSE, 
+##    bootstrap=0, 
+##    progressBar=FALSE)
+## # 0 1.1 1.2 1.3 1.4 1.5 2 3 
+## # ........Done.
+## # MLE of p is between 0 and 1, which is impossible.  
+## # Instead, the MLE of p has been set to NA .  
+## # Please check your data and the call to tweedie.profile().
+## # Error in if ((xi.max == xi.vec[1]) | (xi.max == xi.vec[length(xi.vec)])) { : 
+## # missing value where TRUE/FALSE needed 
+
+
+###################################################
+### code chunk number 76: ChainLadder.Rnw:1421-1422 (eval = FALSE)
 ###################################################
 ## system.file("Excel", package="ChainLadder") 
 
 
 ###################################################
-### code chunk number 75: ChainLadder.Rnw:1248-1249 (eval = FALSE)
+### code chunk number 77: ChainLadder.Rnw:1430-1431 (eval = FALSE)
 ###################################################
 ## system.file("SWord", package="ChainLadder") 
 
 
 ###################################################
-### code chunk number 76: ChainLadder.Rnw:1254-1255 (eval = FALSE)
+### code chunk number 78: ChainLadder.Rnw:1436-1437 (eval = FALSE)
 ###################################################
 ## demo(package="ChainLadder")
 
